{% extends "common/step.jinja" %}
{% block step_content %}
    <h3 class="fs-5">Description</h3>
    <p>
        In this step the numerical subset of the dataset is scaled with method <b>{{ data[i].method }}</b>.
    Below is a snapshot of the dataset after scaling is performed.
    </p>
    {% include "common/table_view.jinja" %}
{% endblock %}